@@ -2,7 +2,8 @@ from typing import Dict, Iterable, List
 from explainaboard.constants import *
 from .loader import register_loader
 from .loader import Loader
-from explainaboard.constants import FileType, Source, TaskType
+from explainaboard.constants import FileType, Source
+from explainaboard.tasks import TaskType
 
 @register_loader(TaskType.named_entity_recognition)
 class NERLoader(Loader):
