@@ -50,7 +50,13 @@ class NERProcessor(Processor):
                                              _number=4,
                                              _setting=())),
             "span_pos":feature.Position(positions=[0,0]),
-            "span_tag":feature.Value("string"),
+            "span_tag":feature.Value(dtype="string",
+                                     description="entity tag",
+                                         is_bucket=True,
+                                         bucket_info=feature.BucketInfo(
+                                             _method="bucket_attribute_discrete_value",
+                                             _number=4,
+                                             _setting=1)),
             "eCon":feature.Value(dtype="float",
                                  description="entity label consistency",
                                          is_bucket=True,
